.. Copyright (C) 2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`RabbitMQ <https://www.rabbitmq.com/>`_ is an Open Source message broker which supports `AMQP <https://en.wikipedia.org/wiki/Advanced_Message_Queuing_Protocol>`_, `STOMP <https://en.wikipedia.org/wiki/Streaming_Text_Oriented_Messaging_Protocol>`_ and `MQTT <https://en.wikipedia.org/wiki/MQTT>`_ protocols.

This Ansible role can be used to install and manage RabbitMQ service on
Debian/Ubuntu hosts.
